# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from notifications_server_connector.models.send_notification_request import SendNotificationRequest  # noqa: E501

class TestSendNotificationRequest(unittest.TestCase):
    """SendNotificationRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SendNotificationRequest:
        """Test SendNotificationRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SendNotificationRequest`
        """
        model = SendNotificationRequest()  # noqa: E501
        if include_optional:
            return SendNotificationRequest(
                source_type_id = None,
                source_id = 56,
                portal_id = 56,
                portal_member_id = 56,
                title = '',
                message = '',
                is_anonymous = True,
                parent_id = 56,
                parent_name = '',
                created_at = 56,
                fcm_topic = '',
                notification_receivers = [
                    56
                    ],
                args = notifications_server_connector.models.args.Args(),
                extra_email_receivers = [
                    ''
                    ],
                subject_override = '',
                body_override = ''
            )
        else:
            return SendNotificationRequest(
                source_type_id = None,
                source_id = 56,
                portal_id = 56,
                portal_member_id = 56,
                title = '',
                message = '',
        )
        """

    def testSendNotificationRequest(self):
        """Test SendNotificationRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr
from notifications_server_connector.models.overridable_source_type_response import OverridableSourceTypeResponse

class PortalTemplateOverrideResponse(BaseModel):
    """
    PortalTemplateOverrideResponse
    """
    source_type_id: StrictInt = Field(...)
    source_type: OverridableSourceTypeResponse = Field(...)
    subject: StrictStr = Field(...)
    body: StrictStr = Field(...)
    is_override: StrictBool = Field(default=..., description="True if portal has custom override")
    created_at: Optional[StrictInt] = None
    updated_at: Optional[StrictInt] = None
    __properties = ["source_type_id", "source_type", "subject", "body", "is_override", "created_at", "updated_at"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PortalTemplateOverrideResponse:
        """Create an instance of PortalTemplateOverrideResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of source_type
        if self.source_type:
            _dict['source_type'] = self.source_type.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PortalTemplateOverrideResponse:
        """Create an instance of PortalTemplateOverrideResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PortalTemplateOverrideResponse.parse_obj(obj)

        _obj = PortalTemplateOverrideResponse.parse_obj({
            "source_type_id": obj.get("source_type_id"),
            "source_type": OverridableSourceTypeResponse.from_dict(obj.get("source_type")) if obj.get("source_type") is not None else None,
            "subject": obj.get("subject"),
            "body": obj.get("body"),
            "is_override": obj.get("is_override"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at")
        })
        return _obj


